.. Torch Uncertainty documentation master file, created by
   sphinx-quickstart on Wed Feb  1 18:07:01 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Torch Uncertainty
=================

.. role:: bash(code)
   :language: bash

Welcome to the documentation of TorchUncertainty.

This website contains the documentation for 
`installing <https://torch-uncertainty.github.io/installation.html>`_
and `contributing <https://torch-uncertainty.github.io/>`_ to TorchUncertainty, 
details on the `API <https://torch-uncertainty.github.io/api.html>`_, and a 
`comprehensive list of the references <https://torch-uncertainty.github.io/references.html>`_  of
the models and metrics implemented.

You can install TorchUncertainty directly from PyPI:

.. parsed-literal::
   pip install torch-uncertainty

To install TorchUncertainty with contribution in mind, check the
`contribution page <https://torch-uncertainty.github.io/contributing.html>`_.

Packed-Ensembles
^^^^^^^^^^^^^^^^

Finally, TorchUncertainty also includes the official PyTorch implementation for
the following paper:

**Packed-Ensembles for Efficient Uncertainty Estimation**

* Authors: *Olivier Laurent, Adrien Lafage, Enzo Tartaglione, Geoffrey Daniel, Jean-Marc Martinez, Andrei Bursuc, and Gianni Franchi*
* Paper: `here <https://arxiv.org/abs/2210.09184>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   quickstart
   introduction_uncertainty
   auto_tutorials/index
   api
   contributing
   references

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
